% This is an example script how to use the function computeManeuver(...) that
% computes quadrotor maneuvers satisfying pontryagin's minimum principle
% with respect to time-optimality

% PERFORMANCE BENCHMARKING OF QUADROTOR SYSTEMS USING TIME-OPTIMAL CONTROL
% Markus Hehn, Robin Ritz, Raffaello D'Andrea
% Institute for Dynamic Systems and Control
% ETH Zurich
% July 2011

% Define parameters
dataFolder = 'quadrotorManeuvers';
functionFolder = 'quadrotorFunctions';
omega_max = 10;
g = 9.81;
isBangbang = 1;

% Clear Command Window
clc;

% Add folder with functions to current search path
path(path,functionFolder);

% Load initial maneuver
load([dataFolder,'/par_xT1.0_zT0.0_dim.mat']);

% Nondimensionalize
par = transformParameters(par,0,omega_max,g);

% Define initial state
x0 = [0;0;0;0;0];

% Define elements of final states
x_lower = 1.1; x_upper = 1.3; x_step = 0.1; % compute maneuvers with a purely horizontal
x = (x_lower:x_step:x_upper)*omega_max^2/g; % displacement between 1.1m and 1.3m with a
                                            % step size of 0.1m

% Define thrust limits
uT_min = par.uT_min;
uT_max = par.uT_max;

% Compute maneuvers
for i = 1:length(x)
    
    % Define final state
    xT = zeros(5,1); xT(1) = x(i);
    
    % Maneuver computation
    par = computeManeuver(x0,xT,uT_min,uT_max,par,isBangbang);

    % Save dimensionless maneuver
    save([dataFolder,'/par_xT',num2str(xT(1)*9.81/100,'%4.1f'),...
          '_zT',num2str(xT(3)*9.81/100,'%4.1f'),'.mat'],'par');
      
    % Dimensionalize
    par_dim = transformParameters(par,1,omega_max,g);
    
    % Save dimensional maneuver
    save([dataFolder,'/par_xT',num2str(xT(1)*9.81/100,'%4.1f'),...
          '_zT',num2str(xT(3)*9.81/100,'%4.1f'),'_dim.mat'],'par_dim');
      
    % Plot computed maneuver
    plotManeuver(par_dim,[1,2]);
    
end
