% This is an example script how to use the function computeManeuver(...) that
% computes quadrotor maneuvers satisfying pontryagin's minimum principle
% with respect to time-optimality

% PERFORMANCE BENCHMARKING OF QUADROTOR SYSTEMS USING TIME-OPTIMAL CONTROL
% Markus Hehn, Robin Ritz, Raffaello D'Andrea
% Institute for Dynamic Systems and Control
% ETH Zurich
% July 2011

% Define parameters
dataFolder = 'quadrotorManeuvers';
functionFolder = 'quadrotorFunctions';
omega_max = 10;
g = 9.81;
isBangbang = 0;

% Clear Command Window
clc;

% Add folder with functions to current search path
path(path,functionFolder);

% Load initial maneuver
load([dataFolder,'/par_xT0.0_zT2.5_dim.mat']);

% Nondimensionalize
par = transformParameters(par,0,omega_max,g);

% Define initial state
x0 = [0;0;0;0;0];

% Define elements of final states
theta = 2*pi;                               % compute maneuvers with a flip and a purely
z_lower = 2.6; z_upper = 2.8; z_step = 0.1; % vertical displacement between 2.6m and 2.8m
z = (z_lower:z_step:z_upper)*omega_max^2/g; % with a step size of 0.1m

% Define thrust limits
uT_min = par.uT_min;
uT_max = par.uT_max;

% Compute maneuvers
for i = 1:length(z)
    
    % Define final state
    xT = zeros(5,1); xT(3) = z(i); xT(5) = theta;
    
    % Maneuver computation
    par = computeManeuver(x0,xT,uT_min,uT_max,par,isBangbang);
    
    % Save dimensionless maneuver
    save([dataFolder,'/par_xT',num2str(xT(1)*9.81/100,'%4.1f'),...
          '_zT',num2str(xT(3)*9.81/100,'%4.1f'),'.mat'],'par');
      
    % Dimensionalize
    par_dim = transformParameters(par,1,omega_max,g);
    
    % Save dimensional maneuver
    save([dataFolder,'/par_xT',num2str(xT(1)*9.81/100,'%4.1f'),...
          '_zT',num2str(xT(3)*9.81/100,'%4.1f'),'_dim.mat'],'par_dim');
      
    % Plot computed maneuver
    plotManeuver(par_dim,[1,2]);
    
end
