function xi = interp1f(t,x,ti)
%INTERP1F Fast linear interpolation.
%   xi = interp1f(t,x,ti) comutes the value of x at time ti, using linear
%   interpolation. t must be a succesively increasing array with n values,
%   x must be a (n x m) matrix, and ti a scalar. The linear interpolation
%   is faster than interp1 since no error checks are performed.

% PERFORMANCE BENCHMARKING OF QUADROTOR SYSTEMS USING TIME-OPTIMAL CONTROL
% Markus Hehn, Robin Ritz, Raffaello D'Andrea
% Institute for Dynamic Systems and Control
% ETH Zurich
% July 2011

% Get indices for interpolation
i_upper = find(ti <= t,1,'first');
if isempty(i_upper) % ti > max(t)
    i_upper = length(t);
    i_lower = i_upper;
elseif i_upper == 1 % ti < min(t)
    i_lower = 1;
else
    i_lower = i_upper - 1;
end

% Interpolate
if i_upper ~= i_lower
    xi = x(i_lower,:) + ...
        (ti-t(i_lower))/(t(i_upper)-t(i_lower)) * ...
        (x(i_upper,:)-x(i_lower,:));
else
    xi = x(i_lower,:);
end

