function plotResidual(par,plot_res_min,plot_T,fig)
%PLOTRESIDUAL Plot residual for each time-step of of the STO.
%   plotResidual(par,plot_res_min,plot_T,fig) plots the residual of each
%   time-step of the current STO execution.

% PERFORMANCE BENCHMARKING OF QUADROTOR SYSTEMS USING TIME-OPTIMAL CONTROL
% Markus Hehn, Robin Ritz, Raffaello D'Andrea
% Institute for Dynamic Systems and Control
% ETH Zurich
% July 2011

% Plot residual versus duration T
if fig(1) > -1
    
    % Read window limits
    nPoints = 6;
    if length(plot_res_min) >= nPoints
        res_max = max(plot_res_min(end-(nPoints-1):end));
        T_min = min(plot_T(end-(nPoints-1):end));
        T_max = max(plot_T(end-(nPoints-1):end));
    else
        res_max = max(plot_res_min);
        T_min = min(plot_T);
        T_max = max(plot_T);
        if length(plot_res_min) == 1
            T_max = 1.1*T_max; % avoid crash when defining axis
        end
    end
    
    % Define plot
    figure(fig(1));
    plot(plot_T,plot_res_min,'-*b',...                             % residual
         [0,1.1*T_max],[par.STO_TolConv,par.STO_TolConv],'--m',... % convexity tolerance
         [0,1.1*T_max],[par.STO_TolRes,par.STO_TolRes],'--g',...   % residual = 0 tolerance
         [0,1.1*T_max],[0,0],'--r');                               % zero
    title('Residual $P_{res}(T)+C_{res}(T)$','Interpreter','latex');
    xlabel('$T$','Interpreter','latex');
    legend({'$P_{res}+C_{res}$','$tolConv$','$tolRes$'},...
           'Location','NorthEast','Interpreter','latex');
    axis([T_min-0.1*(T_max-T_min),T_max+0.1*(T_max-T_min),...
         -0.1*res_max,1.1*res_max]);
end

end

