function uT = thrustInput(t,x,par,pont)
%THRUSTINPUT Compute thrust input uT at time t.
%   uT = thrustInput(t,x,par,pont) computes the thrust input uT at time
%   t, based on the parameters stored in the struct par. The variable
%   pont defines if the input is computet based on the switching function
%   resulting from Pontryagin's minimum principle or based on the switching
%   times stored in par:
%       pont = 1: calculation based on switching function
%       pont = 0: calculation based on switching times par.T_uT

% PERFORMANCE BENCHMARKING OF QUADROTOR SYSTEMS USING TIME-OPTIMAL CONTROL
% Markus Hehn, Robin Ritz, Raffaello D'Andrea
% Institute for Dynamic Systems and Control
% ETH Zurich
% July 2011

% Set pont to default value if empty
if isempty(pont), pont = 0; end

% Interpolate current pitch x(5) if empty
if isempty(x) && pont
    x5 = interp1f(par.t,par.x(:,5),t);
elseif ~isempty(x) && pont
    x5 = x(5);
end

% Compute thrust control input uT
if pont
    if (par.c(2)-par.c(1)*t)*sin(x5)+(par.c(4)-par.c(3)*t)*cos(x5) > 0
        uT = par.uT_min;
    else
        uT = par.uT_max;
    end
else
    if mod(par.uT0_ind + sum(t >= par.T_uT),2)
        uT = par.uT_max;
    else
        uT = par.uT_min;
    end
end

end

